==> apache_airflow-2.0.0b2-py3-none-any.whl: airflow/operators/hive_to_druid.py <==
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
"""This module is deprecated.

Please use `airflow.providers.apache.druid.transfers.hive_to_druid`.
"""

import warnings

# pylint: disable=unused-import
from airflow.providers.apache.druid.transfers.hive_to_druid import HiveToDruidOperator

warnings.warn(
    "This module is deprecated. Please use `airflow.providers.apache.druid.transfers.hive_to_druid`.",
    DeprecationWarning,
    stacklevel=2,
)


class HiveToDruidTransfer(HiveToDruidOperator):
    """This class is deprecated.

    Please use:
    `airflow.providers.apache.druid.transfers.hive_to_druid.HiveToDruidOperator`.
    """

    def __init__(self, **kwargs):
        warnings.warn(
            """This class is deprecated.
            Please use
            `airflow.providers.apache.druid.transfers.hive_to_druid.HiveToDruidOperator`.""",
            DeprecationWarning,
            stacklevel=3,
        )
        super().__init__(**kwargs)

==> apache_airflow-2.4.0.dev20220826-py3-none-any.whl: airflow/operators/hive_to_druid.py <==
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
"""
This module is deprecated.
Please use :mod:`airflow.providers.apache.druid.transfers.hive_to_druid`.
"""

import warnings

from airflow.exceptions import RemovedInAirflow3Warning
from airflow.providers.apache.druid.transfers.hive_to_druid import HiveToDruidOperator

warnings.warn(
    "This module is deprecated. Please use `airflow.providers.apache.druid.transfers.hive_to_druid`.",
    RemovedInAirflow3Warning,
    stacklevel=2,
)


class HiveToDruidTransfer(HiveToDruidOperator):
    """This class is deprecated.

    Please use:
    `airflow.providers.apache.druid.transfers.hive_to_druid.HiveToDruidOperator`.
    """

    def __init__(self, **kwargs):
        warnings.warn(
            """This class is deprecated.
            Please use
            `airflow.providers.apache.druid.transfers.hive_to_druid.HiveToDruidOperator`.""",
            RemovedInAirflow3Warning,
            stacklevel=3,
        )
        super().__init__(**kwargs)
